from cf_extension_core.base_handler import BaseHandler as BaseHandler
from cf_extension_core.interface import (
    CustomResourceHelpers as CustomResourceHelpers,
    generate_dynamodb_resource as generate_dynamodb_resource,
)
